@@ -6,7 +6,7 @@ import time
 import requests
 from requests import Session
 
-from error import TwitterError
+from .error import TwitterError
 
 PUBLIC_TOKEN = "AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu4FA33AGWWjCpTnA"
 
@@ -809,7 +809,7 @@ class Api:
         if not user_id and not screen_name:
             raise TwitterError(f"user_id and screen_name are both null")
         follower_list = []
-        params = self.get_params({"count": count, "stringify_ids": True})
+        params = self.get_params({"count": 5000, "stringify_ids": True})
         if user_id:
             params["user_id"] = user_id
         elif screen_name:
@@ -860,7 +860,7 @@ class Api:
         if not user_id and not screen_name:
             raise TwitterError(f"user_id and screen_name are both null")
         following_list = []
-        params = self.get_params({"count": count, "stringify_ids": True})
+        params = self.get_params({"count": 5000, "stringify_ids": True})
         if user_id:
             params["user_id"] = user_id
         elif screen_name:
